@@ -46,7 +46,7 @@ impl<'a> Background<'a> {
 
     fn attr(&self) -> String {
         let mut doc = String::new();
-        for (attr, member) in &[
+        for (attr, member) in [
             ("", self.src),
             ("-size", self.size),
             ("-position", self.position),
@@ -86,21 +86,23 @@ fn slide_block(slide: &Node, bg: &Background, first_column: bool) -> Result<Stri
         let local_bg = Background::new(slide)?;
         doc += &if local_bg.is_valid() { &local_bg } else { bg }.attr();
     }
-    let mut t = String::new();
-    for (i, title) in ["title", "none-title"].iter().enumerate() {
-        t = slide.get_default(&[*title], "", Node::as_str)?.to_owned();
+    for (i, &title) in ["title", "$title"].iter().enumerate() {
+        t = slide.get_default(&[title], "", Node::as_str)?;
         if !t.is_empty() {
             if i == 1 || first_column {
                 doc += " data-visibility=\"uncounted\"";
             }
-            t = format!("<h2>{}</h2><hr/>", t);
+            doc += ">";
+            doc += &md2html(&format!("# {}", t));
+            doc += "<hr/>";
             break;
         }
+        if i == 1 {
+            doc += ">";
+        }
     }
-    doc += ">";
-    doc += &t;
     doc += &content_block(slide, &mut 0)?;
-    let t = slide.get_default(&["note"], "", Node::as_str)?;
+    t = slide.get_default(&["note"], "", Node::as_str)?;
     if !t.is_empty() {
         doc += &format!("<aside class=\"notes\">{}</aside>", md2html(&t));
     }
@@ -194,7 +196,7 @@ fn load_main(yaml: Array, mount: &str) -> Result<String, Error> {
                 }
                 doc += "<ul>";
                 for (j, slide) in sub.iter().enumerate() {
-                    let t = slide.get(&["title"])?.as_str()?;
+                    let t = slide.get_default(&["title"], "", Node::as_str)?;
                     if t.is_empty() {
                         continue;
                     }
@@ -207,7 +209,7 @@ fn load_main(yaml: Array, mount: &str) -> Result<String, Error> {
         doc += "</section>";
     }
     let mut reveal = TEMPLATE.to_owned().replace("{%mount}", mount);
-    for (key, default) in &[
+    for (key, default) in [
         ("icon", "help/icon.png"),
         ("lang", "en"),
         ("title", &title),
@@ -218,7 +220,7 @@ fn load_main(yaml: Array, mount: &str) -> Result<String, Error> {
     ] {
         reveal = reveal.replace(
             &format!("{{%{}}}", key),
-            meta.get_default(&[*key], *default, Node::as_str)?,
+            meta.get_default(&[key], default, Node::as_str)?,
         );
     }
     reveal = reveal.replace("/* {%option} */", &options(meta)?);
