@@ -21,8 +21,8 @@ where
             copy_dir(&path, dist.join(file_name))?;
         } else if path.is_file() {
             let dist = dist.join(file_name);
-            println!("{:?} > {:?}", &path, dist);
-            copy(&path, dist)?;
+            println!("{} > {}", path.to_str().unwrap(), dist.to_str().unwrap());
+            copy(path, dist)?;
         }
     }
     Ok(())
@@ -55,7 +55,7 @@ where
 }
 
 /// Pack project to an archive.
-pub fn pack<P, D>(path: P, dist: D) -> Result<()>
+pub fn pack<P, D>(path: P, dist: D, project: &str) -> Result<()>
 where
     P: AsRef<Path>,
     D: AsRef<Path>,
@@ -63,15 +63,13 @@ where
     set_current_dir(path.as_ref())?;
     let dist = dist.as_ref();
     if dist.is_dir() {
-        println!("Remove {:?}", &dist);
-        remove_dir_all(&dist)?;
+        println!("Remove {}", dist.to_str().unwrap());
+        remove_dir_all(dist)?;
     }
+    let contents = loader(&read_to_string(project)?, "")?;
     let archive = Path::new(ARCHIVE);
     extract(".")?;
-    write(
-        archive.join("index.html"),
-        loader(&read_to_string(ROOT)?, "")?,
-    )?;
+    write(archive.join("index.html"), contents)?;
     for assets in listdir(".")? {
         if assets.file_name().unwrap() == archive {
             continue;
@@ -79,7 +77,7 @@ where
         if assets.is_dir() {
             let dist = archive.join(assets.file_name().unwrap().to_os_string());
             create_dir(&dist)?;
-            copy_dir(&assets, dist)?;
+            copy_dir(assets, dist)?;
         }
     }
     rename(archive, dist)?;
